@@ -29,23 +29,35 @@ pub trait BlockchainApi: ErrorApi + ManagedTypeApi + Clone + Sized + 'static {
         ManagedAddress::from_address(self.clone(), &self.get_owner_address_legacy())
     }
 
-    fn get_shard_of_address(&self, address: &Address) -> u32;
+    fn get_shard_of_address_legacy(&self, address: &Address) -> u32;
 
-    fn is_smart_contract(&self, address: &Address) -> bool;
-
-    fn get_balance(&self, address: &Address) -> BigUint<Self>;
-
-    fn get_state_root_hash(&self) -> H256;
-
-    #[inline]
-    fn get_state_root_hash_managed(&self) -> ManagedByteArray<Self, 32> {
-        ManagedByteArray::new_from_bytes(self.clone(), self.get_state_root_hash().as_array())
+    fn get_shard_of_address(&self, address: &ManagedAddress<Self>) -> u32 {
+        self.get_shard_of_address_legacy(&address.to_address())
     }
 
-    fn get_tx_hash(&self) -> H256;
+    fn is_smart_contract_legacy(&self, address: &Address) -> bool;
 
-    fn get_tx_hash_managed(&self) -> ManagedByteArray<Self, 32> {
-        ManagedByteArray::new_from_bytes(self.clone(), self.get_tx_hash().as_array())
+    fn is_smart_contract(&self, address: &ManagedAddress<Self>) -> bool {
+        self.is_smart_contract_legacy(&address.to_address())
+    }
+
+    fn get_balance_legacy(&self, address: &Address) -> BigUint<Self>;
+
+    fn get_balance(&self, address: &ManagedAddress<Self>) -> BigUint<Self> {
+        self.get_balance_legacy(&address.to_address())
+    }
+
+    fn get_state_root_hash_legacy(&self) -> H256;
+
+    #[inline]
+    fn get_state_root_hash(&self) -> ManagedByteArray<Self, 32> {
+        ManagedByteArray::new_from_bytes(self.clone(), self.get_state_root_hash_legacy().as_array())
+    }
+
+    fn get_tx_hash_legacy(&self) -> H256;
+
+    fn get_tx_hash(&self) -> ManagedByteArray<Self, 32> {
+        ManagedByteArray::new_from_bytes(self.clone(), self.get_tx_hash_legacy().as_array())
     }
 
     fn get_gas_left(&self) -> u64;
@@ -58,10 +70,10 @@ pub trait BlockchainApi: ErrorApi + ManagedTypeApi + Clone + Sized + 'static {
 
     fn get_block_epoch(&self) -> u64;
 
-    fn get_block_random_seed(&self) -> Box<[u8; 48]>;
+    fn get_block_random_seed_legacy(&self) -> Box<[u8; 48]>;
 
-    fn get_block_random_seed_managed(&self) -> ManagedByteArray<Self, 48> {
-        ManagedByteArray::new_from_bytes(self.clone(), &*self.get_block_random_seed())
+    fn get_block_random_seed(&self) -> ManagedByteArray<Self, 48> {
+        ManagedByteArray::new_from_bytes(self.clone(), &*self.get_block_random_seed_legacy())
     }
 
     fn get_prev_block_timestamp(&self) -> u64;
@@ -72,10 +84,10 @@ pub trait BlockchainApi: ErrorApi + ManagedTypeApi + Clone + Sized + 'static {
 
     fn get_prev_block_epoch(&self) -> u64;
 
-    fn get_prev_block_random_seed(&self) -> Box<[u8; 48]>;
+    fn get_prev_block_random_seed_legacy(&self) -> Box<[u8; 48]>;
 
-    fn get_prev_block_random_seed_managed(&self) -> ManagedByteArray<Self, 48> {
-        ManagedByteArray::new_from_bytes(self.clone(), &*self.get_prev_block_random_seed())
+    fn get_prev_block_random_seed(&self) -> ManagedByteArray<Self, 48> {
+        ManagedByteArray::new_from_bytes(self.clone(), &*self.get_prev_block_random_seed_legacy())
     }
 
     fn get_current_esdt_nft_nonce(
