@@ -16,7 +16,16 @@ pub const ARG_DECODE_ERROR_1: &[u8] = b"argument decode error (";
 pub const ARG_DECODE_ERROR_2: &[u8] = b"): ";
 pub const STORAGE_VALUE_OUT_OF_RANGE: &[u8] = b"storage value out of range";
 pub const STORAGE_DECODE_ERROR: &[u8] = b"storage decode error: ";
+pub const STORAGE_ENCODE_ERROR: &[u8] = b"storage encode error: ";
+pub const STORAGE_KEY_ENCODE_ERROR: &[u8] = b"storage key encode error: ";
+pub const FINISH_ENCODE_ERROR: &[u8] = b"endpoint result encode error: ";
+pub const SERIALIZER_DECODE_ERROR: &[u8] = b"serializer decode error: ";
+pub const SERIALIZER_ENCODE_ERROR: &[u8] = b"serializer encode error: ";
+pub const LOG_TOPIC_ENCODE_ERROR: &[u8] = b"log topic encode error: ";
+pub const LOG_DATA_ENCODE_ERROR: &[u8] = b"log data encode error: ";
+pub const CONTRACT_CALL_ENCODE_ERROR: &[u8] = b"contract call encode error: ";
 
+pub const VALUE_EXCEEDS_SLICE: &[u8] = b"value exceeds target slice";
 pub const BIG_UINT_EXCEEDS_SLICE: &[u8] = b"big uint as_bytes exceed target slice";
 pub const BIG_UINT_SUB_NEGATIVE: &[u8] = b"cannot subtract because result would be negative";
 
