@@ -1,7 +1,7 @@
 use crate::{
     api::{ErrorApi, ManagedTypeApi},
     err_msg,
-    types::{ManagedBuffer, ManagedVec},
+    types::{ManagedBuffer, ManagedType, ManagedVec},
     DynArgInput,
 };
 
@@ -12,20 +12,18 @@ where
     data: ManagedVec<A, ManagedBuffer<A>>,
     data_len: usize,
     next_index: usize,
-    api: A,
 }
 
 impl<A> ManagedResultArgLoader<A>
 where
     A: ManagedTypeApi + ErrorApi,
 {
-    pub fn new(api: A, data: ManagedVec<A, ManagedBuffer<A>>) -> Self {
+    pub fn new(data: ManagedVec<A, ManagedBuffer<A>>) -> Self {
         let data_len = data.len();
         ManagedResultArgLoader {
             data,
             data_len,
             next_index: 0,
-            api,
         }
     }
 }
@@ -39,8 +37,8 @@ where
     type ErrorApi = A;
 
     #[inline]
-    fn error_api(&self) -> Self::ErrorApi {
-        self.api.clone()
+    fn dyn_arg_vm_api(&self) -> Self::ErrorApi {
+        self.data.type_manager()
     }
 
     #[inline]
@@ -53,7 +51,8 @@ where
             self.next_index += 1;
             buffer
         } else {
-            self.error_api().signal_error(err_msg::ARG_WRONG_NUMBER)
+            self.dyn_arg_vm_api()
+                .signal_error(err_msg::ARG_WRONG_NUMBER)
         }
     }
 }
