@@ -29,4 +29,4 @@ pub mod types;
 
 pub use hex_call_data::*;
 pub use io::*;
-pub use storage::{storage_get, storage_set};
+pub use storage::{storage_clear, storage_get, storage_get_len, storage_set};
