@@ -54,9 +54,9 @@ where
     T: ManagedVecItem<M>,
 {
     #[inline]
-    pub fn new_empty(api: M) -> Self {
+    pub fn new(api: M) -> Self {
         ManagedVec {
-            buffer: ManagedBuffer::new_empty(api),
+            buffer: ManagedBuffer::new(api),
             _phantom: PhantomData,
         }
     }
@@ -77,7 +77,7 @@ where
     I: ManagedInto<M, T>,
 {
     fn managed_from(api: M, v: Vec<I>) -> Self {
-        let mut result = Self::new_empty(api.clone());
+        let mut result = Self::new(api.clone());
         for item in v.into_iter() {
             result.push(item.managed_into(api.clone()));
         }
@@ -92,7 +92,7 @@ where
 {
     #[inline]
     fn managed_default(api: M) -> Self {
-        Self::new_empty(api)
+        Self::new(api)
     }
 }
 
@@ -172,10 +172,63 @@ where
     }
 }
 
+impl<M, T> Clone for ManagedVec<M, T>
+where
+    M: ManagedTypeApi,
+    T: ManagedVecItem<M> + Clone,
+{
+    fn clone(&self) -> Self {
+        let mut result = ManagedVec::new(self.type_manager());
+        for item in self.into_iter() {
+            result.push(item.clone())
+        }
+        result
+    }
+}
+
+impl<M, T> PartialEq for ManagedVec<M, T>
+where
+    M: ManagedTypeApi,
+    T: ManagedVecItem<M> + PartialEq,
+{
+    #[inline]
+    fn eq(&self, other: &Self) -> bool {
+        if self.buffer == other.buffer {
+            return true;
+        }
+        let self_len = self.buffer.byte_len();
+        let other_len = other.buffer.byte_len();
+        if self_len != other_len {
+            return false;
+        }
+        let mut byte_index = 0;
+        while byte_index < self_len {
+            let self_item = T::from_byte_reader(self.type_manager(), |dest_slice| {
+                let _ = self.buffer.load_slice(byte_index, dest_slice);
+            });
+            let other_item = T::from_byte_reader(self.type_manager(), |dest_slice| {
+                let _ = other.buffer.load_slice(byte_index, dest_slice);
+            });
+            if self_item != other_item {
+                return false;
+            }
+            byte_index += T::PAYLOAD_SIZE;
+        }
+        true
+    }
+}
+
+impl<M, T> Eq for ManagedVec<M, T>
+where
+    M: ManagedTypeApi,
+    T: ManagedVecItem<M> + PartialEq,
+{
+}
+
 impl<M, T> TopEncode for ManagedVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem<M> + NestedEncode,
 {
     #[inline]
     fn top_encode<O: TopEncodeOutput>(&self, output: O) -> Result<(), EncodeError> {
@@ -195,31 +248,26 @@ where
 impl<M, T> NestedEncode for ManagedVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem<M> + NestedEncode,
 {
     fn dep_encode<O: NestedEncodeOutput>(&self, dest: &mut O) -> Result<(), EncodeError> {
-        if T::NEEDS_RESERIALIZATION {
-            self.len().dep_encode(dest)?;
-            for item in self {
-                item.dep_encode(dest)?;
-            }
-            Ok(())
-        } else {
-            self.buffer.dep_encode(dest)?;
-            Ok(())
+        self.len().dep_encode(dest)?;
+        for item in self {
+            item.dep_encode(dest)?;
         }
+        Ok(())
     }
 }
 
 impl<M, T> TopDecode for ManagedVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem<M> + NestedDecode,
 {
     fn top_decode<I: TopDecodeInput>(input: I) -> Result<Self, DecodeError> {
         let buffer = ManagedBuffer::top_decode(input)?;
         if T::NEEDS_RESERIALIZATION {
-            let mut result = ManagedVec::new_empty(buffer.type_manager());
+            let mut result = ManagedVec::new(buffer.type_manager());
             let mut nested_de_input = ManagedBufferNestedDecodeInput::new(buffer);
             while nested_de_input.remaining_len() > 0 {
                 result.push(T::dep_decode(&mut nested_de_input)?);
@@ -234,19 +282,23 @@ where
 impl<M, T> NestedDecode for ManagedVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem<M> + NestedDecode,
 {
-    fn dep_decode<I: NestedDecodeInput>(_input: &mut I) -> Result<Self, DecodeError> {
-        // TODO: this is more complex and requires more specialization
-        // not immediately needed
-        Err(DecodeError::UNSUPPORTED_OPERATION)
+    fn dep_decode<I: NestedDecodeInput>(input: &mut I) -> Result<Self, DecodeError> {
+        let size = usize::dep_decode(input)?;
+        let api: M = input.read_specialized((), |_| Err(DecodeError::UNSUPPORTED_OPERATION))?;
+        let mut result = ManagedVec::new(api);
+        for _ in 0..size {
+            result.push(T::dep_decode(input)?);
+        }
+        Ok(result)
     }
 }
 
 impl<M, T> TypeAbi for ManagedVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem<M> + TypeAbi,
 {
     /// It is semantically equivalent to any list of `T`.
     fn type_name() -> String {
@@ -269,7 +321,7 @@ pub fn managed_vec_from_slice_of_boxed_bytes<M: ManagedTypeApi>(
     api: M,
     data: &[BoxedBytes],
 ) -> ManagedVec<M, ManagedBuffer<M>> {
-    let mut result = ManagedVec::new_empty(api.clone());
+    let mut result = ManagedVec::new(api.clone());
     for boxed_bytes in data {
         result.push(ManagedBuffer::new_from_bytes(
             api.clone(),
