@@ -1,6 +1,7 @@
 mod big_int;
 mod big_int_cmp;
 mod big_int_operators;
+mod big_int_sign;
 mod big_uint;
 mod big_uint_cmp;
 mod big_uint_operators;
@@ -10,12 +11,15 @@ mod managed_buffer;
 mod managed_byte_array;
 mod managed_conversion;
 mod managed_default;
+mod managed_multi_result_vec;
+mod managed_multi_result_vec_iter;
 mod managed_type_trait;
 mod managed_vec;
 mod managed_vec_item;
 mod managed_vec_iter;
 
 pub use big_int::BigInt;
+pub use big_int_sign::Sign;
 pub use big_uint::BigUint;
 pub use elliptic_curve::{EllipticCurve, EllipticCurveComponents};
 pub use managed_address::ManagedAddress;
@@ -24,6 +28,8 @@ pub(crate) use managed_byte_array::ManagedBufferSizeContext;
 pub use managed_byte_array::ManagedByteArray;
 pub use managed_conversion::{ManagedFrom, ManagedInto};
 pub use managed_default::ManagedDefault;
+pub use managed_multi_result_vec::ManagedMultiResultVec;
+pub use managed_multi_result_vec_iter::ManagedMultiResultVecIterator;
 pub use managed_type_trait::ManagedType;
 pub use managed_vec::{
     managed_vec_from_slice_of_boxed_bytes, managed_vec_of_buffers_to_arg_buffer, ManagedVec,
